@@ -55,12 +55,40 @@ void fix_expression(std::string &str) {
 		}
 		i++;
 	}
-	if(!b) {
-		gsub("x", "\\x", str);
-		gsub("y", "\\y", str);
-		gsub("z", "\\z", str);
-	}
 	CALCULATOR->parseSigns(str);
+	if(!b) {
+		bool in_cit1 = false, in_cit2 = false;
+		for(i = 0; i < str.length(); i++) {
+			if(!in_cit2 && str[i] == '\"') {
+				in_cit1 = !in_cit1;
+			} else if(!in_cit1 && str[i] == '\'') {
+				in_cit2 = !in_cit2;
+			} else if(!in_cit1 && !in_cit2 && (str[i] == 'x' || str[i] == 'y' || str[i] == 'z')) {
+				size_t i2 = str.find_last_of(NOT_IN_NAMES NUMBERS, i);
+				size_t i3 = str.find_first_of(NOT_IN_NAMES NUMBERS, i);
+				if(i2 == std::string::npos) i2 = 0;
+				else i2++;
+				if(i3 == std::string::npos) i3 = str.length();
+				size_t i4 = i2;
+				if(i4 > 0) {
+					i4 = str.find_last_of(NOT_IN_NAMES, i4);
+					if(i4 == std::string::npos) i4 = 0;
+					else i4++;
+				}
+				size_t i5 = i3;
+				if(i5 < str.length()) {
+					i5 = str.find_first_of(NOT_IN_NAMES, i5 - 1);
+					if(i5 == std::string::npos) i5 = str.length();
+				}
+				if((i2 == i3 - 1 || !CALCULATOR->getActiveExpressionItem(str.substr(i2, i3 - i2))) && ((i4 == i2 && i5 == i3) || !CALCULATOR->getActiveExpressionItem(str.substr(i4, i5 - i4)))) {
+					str.insert(i, 1, '\\');
+					i++;
+				} else {
+					i = i5 - 1;
+				}
+			}
+		}
+	}
 }
 
 SmallTextEdit::SmallTextEdit(int r, QWidget *parent) : QPlainTextEdit(parent), i_rows(r) {}
