@@ -31,6 +31,7 @@
 #include <QDesktopServices>
 #include <QToolTip>
 #include <QPlainTextEdit>
+#include <QTextFrame>
 #include <QDebug>
 
 #include <libqalculate/qalculate.h>
@@ -307,6 +308,10 @@ void replace_one(QString &str, const QString &origstr, const QString &newstr, bo
 	}
 }
 
+#define SAVE_SCROLLBAR_POS int vpos = verticalScrollBar()->value(); if(b_reversed) vpos = verticalScrollBar()->maximum() - vpos;
+#define RESTORE_SCROLLBAR_POS verticalScrollBar()->setValue(b_reversed ? verticalScrollBar()->maximum() - vpos : vpos);
+#define SCROLL_TO_BEGINNING verticalScrollBar()->setValue(b_reversed ? verticalScrollBar()->maximum() : 0);
+
 void HistoryView::loadInitial(bool reload) {
 	if(reload && !initial_loaded) return;
 	s_text.clear();
@@ -340,7 +345,7 @@ void HistoryView::loadInitial(bool reload) {
 		}
 	}
 	if(settings->v_expression.empty()) {
-		if(!settings->clear_history_on_exit && !reload) {
+		if(!settings->clear_history_on_exit && !reload && !b_reversed) {
 			setHtml("<body color=\"" + text_color.name() + "\">" + tr("Type a mathematical expression above, e.g. \"5 + 2 / 3\", and press the enter key.") + "</body>");
 		} else {
 			setHtml("<body color=\"" + text_color.name() + "\"></body>");
@@ -381,8 +386,8 @@ void HistoryView::loadInitial(bool reload) {
 	QFontMetrics fm(font());
 	prev_fonti = fm.boundingRect("Öy");
 	if(b_reversed) {
-		previous_cursor = textCursor().position();
-		previous_cursor2 = previous_cursor;
+		previous_cursor2 = textCursor().position();
+		updateTopMargin();
 	}
 }
 
@@ -390,6 +395,17 @@ void HistoryView::loadInitial(bool reload) {
 	int paste_h = fm.ascent() * 0.75; \
 	if(paste_h < 12) paste_h = 12;
 
+void HistoryView::updateTopMargin() {
+	if(!b_reversed) return;
+	int dh = document()->size().height();
+	int h = height();
+	QTextFrameFormat ffmt = document()->rootFrame()->frameFormat();
+	dh -= ffmt.topMargin();
+	if(dh - ffmt.bottomMargin() * 2 < h) ffmt.setTopMargin(h - dh - ffmt.bottomMargin());
+	else ffmt.setTopMargin(ffmt.bottomMargin());
+	document()->rootFrame()->setFrameFormat(ffmt);
+}
+
 void HistoryView::clearTemporary() {
 	if(!previous_temporary || previous_html.isEmpty()) return;
 	QTextCursor cur = textCursor();
@@ -404,12 +420,13 @@ void HistoryView::clearTemporary() {
 		else cur.setPosition(0, QTextCursor::KeepAnchor);
 		setTextCursor(cur);
 		cur.deleteChar();
+		if(b_reversed) previous_cursor = textCursor().position();
 		insertHtml("<table width=\"100%\">" + previous_html2 + "</table>");
 		previous_html = previous_html2;
 		if(!b_reversed) previous_cursor = textCursor().position();
 	} else {
 		previous_html.clear();
-		if(!b_reversed) previous_cursor = 0;
+		previous_cursor = 0;
 	}
 	previous_temporary = false;
 	i_pos = i_pos2;
@@ -422,6 +439,10 @@ void HistoryView::clearTemporary() {
 	previous_html2.clear();
 	last_ans2 = 0;
 	last_ref2 = "";
+	if(b_reversed) {
+		SCROLL_TO_BEGINNING
+		updateTopMargin();
+	}
 }
 
 bool HistoryView::testTemporaryResultLength(const std::string &str) {
@@ -781,7 +802,10 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			i_pos_p2 = i_pos_p;
 			last_ans2 = last_ans;
 			last_ref2 = last_ref;
-			if(b_reversed) moveCursor(QTextCursor::End);
+			if(b_reversed) {
+				SCROLL_TO_BEGINNING
+				updateTopMargin();
+			}
 		}
 	} else {
 		if(initial_load) {
@@ -789,12 +813,15 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 				QTextCursor cur = textCursor();
 				if(b_reversed) cur.movePosition(QTextCursor::End);
 				else cur.setPosition(0);
-				if(b_reversed) previous_cursor = textCursor().position();
 				setTextCursor(cur);
+				if(b_reversed) previous_cursor = textCursor().position();
 				insertHtml("<table width=\"100%\">" + str + "</table>");
 				previous_html = str;
 				if(!b_reversed) previous_cursor = textCursor().position();
-				if(b_reversed) moveCursor(QTextCursor::End);
+				if(b_reversed) {
+					SCROLL_TO_BEGINNING
+					updateTopMargin();
+				}
 			} else {
 				if(b_reversed) s_text += "<table width=\"100%\">" + str + "</table>";
 				else s_text.insert(0, "<table width=\"100%\">" + str + "</table>");
@@ -815,12 +842,15 @@ void HistoryView::addResult(std::vector<std::string> values, std::string express
 			QTextCursor cur = textCursor();
 			if(b_reversed) cur.movePosition(QTextCursor::End);
 			else cur.setPosition(0);
-			if(b_reversed) previous_cursor = textCursor().position();
 			setTextCursor(cur);
+			if(b_reversed) previous_cursor = textCursor().position();
 			insertHtml("<table width=\"100%\">" + str + "</table>");
 			previous_html = str;
 			if(!b_reversed) previous_cursor = textCursor().position();
-			if(b_reversed) moveCursor(QTextCursor::End);
+			if(b_reversed) {
+				SCROLL_TO_BEGINNING
+				updateTopMargin();
+			}
 		}
 	}
 	previous_temporary = temporary;
@@ -992,6 +1022,14 @@ void HistoryView::inputMethodEvent(QInputMethodEvent *e) {
 		expressionEdit->inputMethodEvent(e);
 	}
 }
+void HistoryView::resizeEvent(QResizeEvent *e) {
+	QTextEdit::resizeEvent(e);
+	if(b_reversed) {
+		SCROLL_TO_BEGINNING
+		updateTopMargin();
+	}
+}
+
 void HistoryView::editClear() {
 	for(size_t i1 = 0; i1 < settings->v_protected.size();) {
 		if(!settings->v_protected[i1]) {
@@ -1010,7 +1048,7 @@ void HistoryView::editClear() {
 			i1++;
 		}
 	}
-	verticalScrollBar()->setValue(0);
+	SCROLL_TO_BEGINNING
 	reloadHistory();
 }
 void HistoryView::editMoveToTop() {
@@ -1042,14 +1080,14 @@ void HistoryView::editMoveToTop() {
 	settings->v_value.erase(settings->v_value.begin() + i1);
 	settings->v_messages.erase(settings->v_messages.begin() + i1);
 	settings->v_parseerror.erase(settings->v_parseerror.begin() + i1);
-	verticalScrollBar()->setValue(0);
+	SCROLL_TO_BEGINNING
 	reloadHistory();
 }
 void HistoryView::reloadHistory() {
-	int vpos = verticalScrollBar()->value();
+	SAVE_SCROLLBAR_POS
 	loadInitial(true);
 	emit historyReloaded();
-	verticalScrollBar()->setValue(vpos);
+	RESTORE_SCROLLBAR_POS
 }
 void HistoryView::editRemove() {
 	int i1 = -1, i2 = -1;
@@ -1084,9 +1122,9 @@ void HistoryView::editRemove() {
 		settings->v_messages.erase(settings->v_messages.begin() + i1);
 		settings->v_parseerror.erase(settings->v_parseerror.begin() + i1);
 	}
-	int vpos = verticalScrollBar()->value();
+	SAVE_SCROLLBAR_POS
 	reloadHistory();
-	verticalScrollBar()->setValue(vpos);
+	RESTORE_SCROLLBAR_POS
 }
 void HistoryView::editComment(int i1, int i2) {
 	bool b_edit = !settings->v_result[i1][i2].empty() && settings->v_result[i1][i2][0] == '#';
@@ -1123,9 +1161,9 @@ void HistoryView::editComment(int i1, int i2) {
 			if(b_edit) {
 				if(settings->v_result[i1][i2] != str.toStdString()) {
 					settings->v_result[i1][i2] = str.toStdString();
-					int vpos = verticalScrollBar()->value();
+					SAVE_SCROLLBAR_POS
 					reloadHistory();
-					verticalScrollBar()->setValue(vpos);
+					RESTORE_SCROLLBAR_POS
 				}
 			} else if(!settings->history_answer.empty() && i1 == (int) settings->v_result.size() - 1 && i2 == 0) {
 				std::vector<std::string> values;
@@ -1136,9 +1174,9 @@ void HistoryView::editComment(int i1, int i2) {
 				settings->v_result[i1].insert(settings->v_result[i1].begin(), str.toStdString());
 				settings->v_exact[i1].insert(settings->v_exact[i1].begin(), settings->v_exact[i1][i2]);
 				settings->v_value[i1].insert(settings->v_value[i1].begin(), settings->v_value[i1][i2]);
-				int vpos = verticalScrollBar()->value();
+				SAVE_SCROLLBAR_POS
 				reloadHistory();
-				verticalScrollBar()->setValue(vpos);
+				RESTORE_SCROLLBAR_POS
 			}
 		}
 	}
@@ -1157,9 +1195,9 @@ void HistoryView::editProtect() {
 	if(i1 < 0 || i1 >= (int) settings->v_protected.size()) return;
 	settings->v_protected[i1] = protectAction->isChecked();
 	if(i1 == 0) settings->current_result = NULL;
-	int vpos = verticalScrollBar()->value();
+	SAVE_SCROLLBAR_POS
 	reloadHistory();
-	verticalScrollBar()->setValue(vpos);
+	RESTORE_SCROLLBAR_POS
 }
 void HistoryView::indexAtPos(const QPoint &pos, int *expression_index, int *result_index, int *value_index, QString *anchorstr) {
 	*expression_index = -1;
