@@ -64,6 +64,7 @@ class PreferencesDialog : public QDialog {
 		void parsingModeChanged(int);
 		void unknownsToggled(bool);
 		void temperatureCalculationChanged(int);
+		void defaultCurrencyChanged(const QString&);
 		void exratesToggled(bool);
 		void exratesChanged(int);
 		void unitsToggled(bool);
@@ -90,6 +91,8 @@ class PreferencesDialog : public QDialog {
 		void resultFontToggled(bool);
 		void expressionFontClicked();
 		void expressionFontToggled(bool);
+		void statusFontClicked();
+		void statusFontToggled(bool);
 		void keypadFontClicked();
 		void keypadFontToggled(bool);
 		void appFontClicked();
@@ -141,6 +144,7 @@ class PreferencesDialog : public QDialog {
 		void titleTypeChanged();
 		void resultFontChanged();
 		void expressionFontChanged();
+		void statusFontChanged();
 		void keypadFontChanged();
 		void appFontChanged();
 		void symbolsUpdated();
