@@ -30,6 +30,7 @@ bool can_display_unicode_string_function(const char *str, void *w);
 
 #define LOAD_APP_ICON(x) QIcon(":/icons/apps/scalable/" x ".svg")
 #define LOAD_ICON(x) load_icon(x, this)
+#define LOAD_COLORED_ICON(x) settings->loadColoredIcon(x, this)
 
 #define USE_QUOTES(arg, f) (arg && (arg->suggestsQuotes() || arg->type() == ARGUMENT_TYPE_TEXT) && f->id() != FUNCTION_ID_BASE && f->id() != FUNCTION_ID_BIN && f->id() != FUNCTION_ID_OCT && f->id() != FUNCTION_ID_DEC && f->id() != FUNCTION_ID_HEX)
 
@@ -55,6 +56,36 @@ void base_from_string(std::string str, int &base, Number &nbase, bool input_base
 long int get_fixed_denominator_qt(const std::string &str, int &to_fraction, const QString &localized_fraction, bool qalc_command = false);
 bool is_equation_solutions(const MathStructure &m);
 
+#ifndef CLOCK_MONOTONIC
+#	define PREPARE_TIMECHECK(ms) \
+					struct timeval tv_end; \
+					gettimeofday(&tv_end, NULL); \
+					tv_end.tv_usec += ((ms) % 1000) * 1000; \
+					tv_end.tv_sec += ((ms) / 1000); \
+					if(tv_end.tv_usec >= 1000000L) { \
+						tv_end.tv_sec++; \
+						tv_end.tv_usec -= 1000000L; \
+					}
+#	define DO_TIMECHECK \
+					struct timeval tv; \
+					gettimeofday(&tv, NULL); \
+					if(tv.tv_sec > tv_end.tv_sec || (tv.tv_sec == tv_end.tv_sec && tv.tv_usec >= tv_end.tv_usec))
+#else
+#	define PREPARE_TIMECHECK(ms) \
+					struct timespec tv_end; \
+					clock_gettime(CLOCK_MONOTONIC, &tv_end); \
+					tv_end.tv_nsec += ((ms) % 1000) * 1000000L; \
+					tv_end.tv_sec += ((ms) / 1000); \
+					if(tv_end.tv_nsec >= 1000000000L) { \
+						tv_end.tv_sec++; \
+						tv_end.tv_nsec -= 1000000000L; \
+					}
+#	define DO_TIMECHECK \
+					struct timespec tv; \
+					clock_gettime(CLOCK_MONOTONIC, &tv); \
+					if(tv.tv_sec > tv_end.tv_sec || (tv.tv_sec == tv_end.tv_sec && tv.tv_nsec >= tv_end.tv_nsec))
+#endif
+
 enum {
 	TITLE_APP,
 	TITLE_RESULT,
@@ -209,6 +240,8 @@ class QalculateQtSettings : QObject {
 		void updateMessagePrintOptions();
 		void updateFavourites();
 		void setCustomAngleUnit();
+		void setDefaultCurrency();
+		QIcon loadColoredIcon(const QString &str, QWidget*);
 		bool checkExchangeRates(QWidget *parent);
 		void fetchExchangeRates(int timeout, int n = -1, QWidget *parent = NULL);
 		bool displayMessages(QWidget *parent);
@@ -222,6 +255,7 @@ class QalculateQtSettings : QObject {
 		void autoUpdate(std::string new_version, QWidget *parent);
 		const char *multiplicationSign(bool units = false);
 		const char *divisionSign(bool output = true);
+		std::string replaceResultSeparators(std::string str);
 		std::string localizeExpression(std::string, bool unit_expression = false);
 		std::string unlocalizeExpression(std::string);
 		bool loadWorkspace(const char *filename);
@@ -231,12 +265,12 @@ class QalculateQtSettings : QObject {
 
 		EvaluationOptions evalops;
 		PrintOptions printops;
-		bool complex_angle_form, dot_question_asked, implicit_question_asked, adaptive_interval_display, tc_set, rpn_mode, chain_mode, caret_as_xor, ignore_locale, do_imaginary_j, fetch_exchange_rates_at_startup, always_on_top, display_expression_status, prefixes_default, rpn_keys, sinc_set;
+		bool complex_angle_form, dot_question_asked, implicit_question_asked, assumptions_warning_shown, adaptive_interval_display, tc_set, rpn_mode, chain_mode, caret_as_xor, ignore_locale, do_imaginary_j, fetch_exchange_rates_at_startup, always_on_top, display_expression_status, prefixes_default, rpn_keys, sinc_set;
 		bool automatic_digit_grouping;
 		int simplified_percentage;
 		bool programming_base_changed;
 		int previous_precision;
-		std::string custom_angle_unit;
+		std::string custom_angle_unit, default_currency;
 		QString custom_lang;
 		int rounding_mode;
 		int allow_multiple_instances;
@@ -252,14 +286,16 @@ class QalculateQtSettings : QObject {
 		bool format_result;
 		bool first_time;
 		bool enable_input_method;
-		bool use_custom_result_font, use_custom_expression_font, use_custom_keypad_font, use_custom_app_font;
-		bool save_custom_result_font, save_custom_expression_font, save_custom_keypad_font, save_custom_app_font;
+		bool use_custom_result_font, use_custom_expression_font, use_custom_keypad_font, use_custom_app_font, use_custom_status_font;
+		bool save_custom_result_font, save_custom_expression_font, save_custom_keypad_font, save_custom_app_font, save_custom_status_font;
 		QFont saved_app_font;
 		int replace_expression;
 		bool autocopy_result;
 		int default_signed = -1, default_bits = -1;
 		int keypad_type;
-		bool separate_keypad_menu_buttons;
+		bool separate_keypad_menu_buttons, show_percent_in_numpad;
+		int expression_pos;
+		bool show_statusbar;
 		int toolbar_style;
 		int show_keypad;
 		int show_bases;
@@ -268,11 +304,11 @@ class QalculateQtSettings : QObject {
 		bool save_defs_on_exit, save_mode_on_exit, clear_history_on_exit;
 		int max_history_lines;
 		bool rpn_shown;
-		bool auto_calculate, status_in_history, autocalc_selection;
+		bool auto_calculate, status_in_history, status_in_statusbar, autocalc_selection;
 		int history_expression_type;
 		bool copy_ascii, copy_ascii_without_units;
 		bool close_with_esc;
-		std::string custom_result_font, custom_expression_font, custom_keypad_font, custom_app_font;
+		std::string custom_result_font, custom_expression_font, custom_keypad_font, custom_app_font, custom_status_font;
 		KnownVariable *vans[5], *v_memory;
 		MathStructure *current_result;
 		MathFunction *f_answer;
@@ -285,6 +321,7 @@ class QalculateQtSettings : QObject {
 		QByteArray datasets_geometry, datasets_vsplitter_state, datasets_hsplitter_state;
 		bool disable_cursor_blinking;
 		bool wayland_platform;
+		QStringList tempfiles;
 
 		int preserve_history_height;
 		bool keypad_appended, bases_appended;
